@@ -44,14 +44,18 @@ class WebAppFeature(AppFeature):
         self.PROMETHEUS_ROUTE_METRIC = Counter(
             'route',
             documentation='Total route calls',
-            labelnames=('path', 'status'),
+            labelnames=('path', 'method', 'status'),
             namespace=self.app.NAME,
         )
 
         @web.middleware
         async def prometheus_route_call_count(request: web.Request, handler) -> web.Response:
-            resp = await handler(request)
-            self.PROMETHEUS_ROUTE_METRIC.labels(request.match_info.route.resource.canonical, resp.status).inc()
+            resp: web.Response = await handler(request)
+            self.PROMETHEUS_ROUTE_METRIC.labels(
+                request.match_info.route.resource.canonical,
+                request.method,
+                resp.status
+            ).inc()
             return resp
 
         self.aiohttp_app = web.Application(
